%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Technical Note 168
% Parameters for 'Grid Forming Inverter' system
% Copyright imperix ltd, 2024
% dev@imperix.ch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% SYSTEM PARAMETERS

SwitchingFreq = 50e3;           % Switching frequency [Hz]
ControlFreq = SwitchingFreq;    % Control frequency [Hz]
ControlPeriod = 1/ControlFreq;  % Control period [s]
SamplingPhase = 0.5;            % Sampling phase [-]

Vdc0 = 800;                     % Initial DC voltage [V]
Freq = 50;                      % Grid frequency [Hz]
Lg = 0.95e-3;                   % TPI main inductor value [H]
Rg = 54e-3;                     % Series equivalent resistance of Lg [ohm]
Cf = 12.9e-6;                   % Capacitance of the filter [F]

%% GRID CURRENT CONTROLLER PARAMETERS

% Optimum magnitude criterion
K1 = 1/Rg;
T1 = Lg/Rg;

% Control Delay @50kHz: 1/2Ts control delay, 1/2Ts modulator delay, 1/2Ts
% for synchronous averaging delay 

Td1 = (1/2 + 1/2 + 1/2)*ControlPeriod;

Tn1 = T1;
Ti1 = 2*K1*Td1;
Kp_I = Tn1/Ti1;
Ki_I = 1/Ti1;

%% GRID VOLTAGE CONTROLLER PARAMETERS

% Symmetrical optimum criterion
T2 = Cf;
Tdeq = 10*Td1;
a = 2;

Ti2 = a^2*Tdeq;
Kp_V = T2/(a*Tdeq);
Ki_V = Kp_V/Ti2;